using System;
using System.IO;
using System.Collections.Generic;

namespace Siberix.Examples
{
	class Example
	{
		private class Item
		{
			public string Title;
			public int Quantity;
			public Decimal UnitPrice;

			public Decimal TotalPrice
			{
				get
				{
					return UnitPrice * Quantity;
				}
			}
		}

		private class Invoice
		{
			public string ContactPhone = "(555) 555 - 5555";
			public string ContactFax = "(555) 555 - 7777";
			public string BillToName = "Contact name";
			public string BillToAddress = "Contact address";
			public string ShipToName = "Contact name";
			public string ShipToAddress = "Contact address";
			public Decimal Total;

			public List<Item> Items = new List<Item>();

			public Invoice()
			{
				// Items
				System.Random rnd = new System.Random();

				int cnt = 66;

				for (int i = 1; i < cnt; i++)
				{
					Item item = new Item();

					item.Title = "Item " + i;
					item.Quantity = rnd.Next(5) + 1;
					item.UnitPrice = rnd.Next(500) + (Decimal)rnd.Next(100) / 100;

					Items.Add(item);

					Total += item.TotalPrice;
				}
			}
		}

		static void Main(string[] args)
		{
			// Report
			Siberix.Report.Report report = new Siberix.Report.Report();

			Invoice invoice = new Invoice();

			report.DataContext = new Siberix.Report.Data.DataContext("dc1", invoice);

			report.Delegates.OnTextInjectorDelegate = delegate(string id, Siberix.Report.Text.IText text, Siberix.Report.Text.Style style, Siberix.Report.Text.Hyperlink hyperlink)
			{
				if (id == "ContactEmail")
					text.AddContent("contact@domain.com", style, new Siberix.Report.Text.Hyperlink("mailto:contact@domain.com"));
			};

			// Load
			report.Load("../../Invoice.xml");

			// Publish
			report.Publish("Document.pdf", Siberix.Report.FileFormat.PDF);
			report.Publish("Document.xps", Siberix.Report.FileFormat.XPS);

			// View
			System.Diagnostics.Process process = new System.Diagnostics.Process();
			System.Diagnostics.ProcessStartInfo info = new System.Diagnostics.ProcessStartInfo("Document.pdf");
			process.StartInfo = info;
			process.Start();
		}
	}
}