using System;
using System.IO;

namespace Siberix.Examples
{
	class Example
	{
		static void Main(string[] args)
		{
			// Report
			Siberix.Report.Report report = new Siberix.Report.Report();

			// Info
			report.Info.Title = "Example";
			report.Info.Author = "Siberix Technologies, Canada";
			report.Info.Creator = "Siberix Report Writer";
			report.Info.Copyright = "2003-2012 Siberix Technologies, Canada";

			// Section
			Siberix.Report.Section.ISection section = report.AddSection();
			section.Size = Siberix.Report.PageSize.Letter;
			section.Spacings.All = 35;

			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(12), Siberix.Graphics.Brushes.Black);
			Siberix.Report.Text.Style style2 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(10), Siberix.Graphics.Brushes.DarkGreen);
			Siberix.Report.Text.Style style3 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.ArialBold(12), Siberix.Graphics.Brushes.DarkBlue);
			Siberix.Report.Text.Style style4 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(38), Siberix.Graphics.Brushes.Red);

			// Flow
			Siberix.Report.Flow.IFlow flow = section.AddFlow();

			Siberix.Report.Flow.IColumn column = flow.AddColumn();
			column.Width = new Siberix.Report.RelativeWidth(50);
			column.Borders.Right = new Siberix.Report.Border(Siberix.Graphics.Pens.DarkBlue);
			column.Paddings.Right = 10;

			column = flow.AddColumn();
			column.Width = new Siberix.Report.RelativeWidth(50);
			column.Paddings.Left = 10;

			// Left-aligned paragraph
			Siberix.Report.Text.IText text = flow.AddText();
			text.Style = style3;
			text.KeepWithNext = true;
			text.AddContent("Left-aligned paragraph");

			text = flow.AddText();
			text.Style = style1;
			text.Interval = 2;
			text.Indent = 50;
			text.Spacings.Top = 10;
			text.Spacings.Bottom = 20;
			text.Alignment = Siberix.Report.TextAlignment.Left;
			text.AddContent("Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");

			// Right-aligned paragraph
			text = flow.AddText();
			text.Style = style3;
			text.KeepWithNext = true;
			text.AddContent("Right-aligned paragraph");

			text = flow.AddText();
			text.Style = style1;
			text.Interval = 2;
			text.Indent = 50;
			text.Spacings.Top = 10;
			text.Spacings.Bottom = 20;
			text.Alignment = Siberix.Report.TextAlignment.Right;
			text.AddContent("Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");

			// Centered paragraph
			text = flow.AddText();
			text.Style = style3;
			text.KeepWithNext = true;
			text.AddContent("Centered paragraph");

			text = flow.AddText();
			text.Style = style1;
			text.Interval = 2;
			text.Spacings.Top = 10;
			text.Spacings.Bottom = 20;
			text.Alignment = Siberix.Report.TextAlignment.Center;
			text.AddContent("Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");

			// Justified paragraph
			text = flow.AddText();
			text.Style = style3;
			text.KeepWithNext = true;
			text.AddContent("Justified paragraph");

			text = flow.AddText();
			text.Style = style1;
			text.Interval = 2;
			text.Indent = 50;
			text.Spacings.Top = 10;
			text.Spacings.Bottom = 20;
			text.Alignment = Siberix.Report.TextAlignment.Justify;
			text.AddContent("Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");

			// Multiple styles
			text = flow.AddText();
			text.Style = style3;
			text.KeepWithNext = true;
			text.AddContent("Multiple styles");

			text = flow.AddText();
			text.Style = style1;
			text.Interval = 2;
			text.Indent = 50;
			text.Spacings.Top = 10;
			text.Spacings.Bottom = 30;
			text.Alignment = Siberix.Report.TextAlignment.Justify;
			text.AddContent("Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. ");
			text.AddContent("Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.", style2);

			// Text with a leader
			text = flow.AddText();
			text.Style = style3;
			text.AddContent("Text with a leader");

			text = flow.AddText();
			text.Style = style1;
			text.Interval = 2;
			text.Spacings.Top = 10;
			text.Spacings.Bottom = 20;
			text.Leader = new Siberix.Report.Text.Leader(".");
			text.AddContent("Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");

			// Text with a drop-cap
			text = flow.AddText();
			text.Style = style3;
			text.AddContent("Text with a drop-cap");

			text = flow.AddText();
			text.Style = style1;
			text.Interval = 2;
			text.Spacings.Top = 10;
			text.Spacings.Bottom = 20;
			text.DropCap = new Siberix.Report.Text.DropCap('A', style4);
			text.DropCap.Spacings.Right = 7;

			text.AddContent("marone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");

			// Publish
			report.Publish("Document.pdf", Siberix.Report.FileFormat.PDF);
			report.Publish("Document.xps", Siberix.Report.FileFormat.XPS);

			// Save
			report.Save("Document.xml");

			// View
			System.Diagnostics.Process process = new System.Diagnostics.Process();
			System.Diagnostics.ProcessStartInfo info = new System.Diagnostics.ProcessStartInfo("Document.pdf");
			process.StartInfo = info;
			process.Start();
		}
	}
}