using System.Collections.Generic;

namespace Siberix.Examples
{
	using System;

	class Example
	{
		static void Main(string[] args)
		{
			// Report
			Siberix.Report.Report report = new Siberix.Report.Report();

			// Info
			report.Info.Title = "Example";
			report.Info.Author = "Siberix Technologies, Canada";
			report.Info.Creator = "Siberix Report Writer";
			report.Info.Copyright = "2003-2012 Siberix Technologies, Canada";

			// Section
			Siberix.Report.Section.ISection section = report.AddSection();
			section.Size = Siberix.Report.PageSize.Letter;
			section.Spacings.All = 35;

			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(12), Siberix.Graphics.Brushes.Black);
			Siberix.Report.Text.Style style2 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(12), Siberix.Graphics.Brushes.Red);
			Siberix.Report.Text.Style style3 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(12), Siberix.Graphics.Brushes.Green);

			// List
			Siberix.Report.List.IList list = section.AddList();
			list.Indent = 20;
			list.Interval = 5;
			list.Bullets.Type = Siberix.Report.BulletType.Decimal;
			list.Bullets.Template = "{0}.";
			list.Bullets.Style = style1;

			Siberix.Report.List.IItem item = list.AddItem();

			Siberix.Report.Text.IText text = item.AddText();
			text.Style = style1;
			text.AddContent("List item");

			item = list.AddItem();

			text = item.AddText();
			text.Style = style1;
			text.AddContent("List item");

			Siberix.Report.List.IList sublist = item.AddList();
			sublist.Spacings.Vertical = 5;
			sublist.Indent = 20;
			sublist.Interval = 5;
			sublist.Bullets.Type = Siberix.Report.BulletType.SmallLetters;
			sublist.Bullets.Template = "{0})";
			sublist.Bullets.Style = style2;

			item = sublist.AddItem();

			text = item.AddText();
			text.Style = style1;
			text.AddContent("Sublist item");

			item = sublist.AddItem();

			text = item.AddText();
			text.Style = style1;
			text.AddContent("Sublist item");

			item = sublist.AddItem();

			text = item.AddText();
			text.Style = style1;
			text.AddContent("Sublist item");

			item = list.AddItem();

			text = item.AddText();
			text.Style = style1;
			text.AddContent("List item");

			sublist = item.AddList();
			sublist.Spacings.Vertical = 5;
			sublist.Indent = 15;
			sublist.Interval = 5;
			sublist.Bullets.Type = Siberix.Report.BulletType.Square;
			sublist.Bullets.Template = "{0}";
			sublist.Bullets.Style = style2;

			Random rnd = new Random();

			for (int i = 0; i < 15; i++)
			{
				item = sublist.AddItem();

				text = item.AddText();
				text.Style = style1;
				text.AddContent("Sublist item " + (i + 1).ToString());
				text.Spacings.Bottom = 5;

				Siberix.Report.IGroup group = item.AddGroup();
				group.Width = new Siberix.Report.RelativeWidth(rnd.Next(50, 100));
				group.Background.Brush = Siberix.Graphics.Brushes.Lavender;
				group.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black, 5);
				group.Paddings.All = 5;
				group.Spacings.Bottom = 5;

				text = group.AddText();
				text.Style = style1;
				text.Alignment = Siberix.Report.TextAlignment.Justify;
				text.AddContent("Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive");
				text.AddContent(" \"raisiny\" ", style3);
				text.AddContent("flavor.");
			}

			// Publish
			report.Publish("Document.pdf", Siberix.Report.FileFormat.PDF);
			report.Publish("Document.xps", Siberix.Report.FileFormat.XPS);

			// Save
			report.Save("Report.xml");

			// View
			System.Diagnostics.Process process = new System.Diagnostics.Process();
			System.Diagnostics.ProcessStartInfo info = new System.Diagnostics.ProcessStartInfo("Document.pdf");
			process.StartInfo = info;
			process.Start();
		}
	}
}