using System;
using System.IO;

namespace Siberix.Examples
{
	class Example
	{
		static void Main(string[] args)
		{
			// Report
			Siberix.Report.Report report = new Siberix.Report.Report();

			// Extension Factory
			report.RegisterExtensionFactory("Factory1", new ExtensionFactory());

			// Info
			report.Info.Title = "Example";
			report.Info.Author = "Siberix Technologies, Canada";
			report.Info.Creator = "Siberix Report Writer";
			report.Info.Copyright = "2003-2012 Siberix Technologies, Canada";

			// Section
			Siberix.Report.Section.ISection section = report.AddSection();
			section.Size = Siberix.Report.PageSize.Letter;
			section.Spacings.All = 35;

			Siberix.Report.IFrame frame = section.AddFrame("Factory1", "TextOnCircle");

			Siberix.ReportWriter.Extensions.TextOnCircle extension = (Siberix.ReportWriter.Extensions.TextOnCircle)frame.Extension;

			extension.Text = "Text On Circle - Custom Report Writer Extension...";
			extension.Font = new Siberix.Graphics.Fonts.TimesNewRoman(25);
			extension.Color = Siberix.Graphics.Colors.DarkBlue;
			extension.Radius = 100.0F;
			extension.Angle = 0.0F;

			// Publish
			report.Publish("Document.pdf", Siberix.Report.FileFormat.PDF);
			report.Publish("Document.xps", Siberix.Report.FileFormat.XPS);

			// Save
			report.Save("Report.xml");

			// View
			System.Diagnostics.Process process = new System.Diagnostics.Process();
			System.Diagnostics.ProcessStartInfo info = new System.Diagnostics.ProcessStartInfo("Document.pdf");
			process.StartInfo = info;
			process.Start();

			/*
			Siberix.Report.Report report2 = new Siberix.Report.Report();
			report2.RegisterExtensionFactory("Factory1", new ExtensionFactory());
			report2.Load("Report.xml");
			report2.Publish("Example2.pdf", Siberix.Report.FileFormat.PDF);
			 */
		}

		public class ExtensionFactory : Siberix.Report.IExtensionFactory
		{
			public Siberix.Report.IExtension CreateExtension(string id)
			{
				if (string.IsNullOrEmpty(id))
					return null;

				if (id.Equals("TextOnCircle"))
					return new Siberix.ReportWriter.Extensions.TextOnCircle("Factory1", "TextOnCircle");

				return null;
			}
		}
	}
}