using System;
using System.IO;
using System.Security.Cryptography.X509Certificates;

namespace Siberix.Examples
{
	class Example
	{
		static void Main(string[] args)
		{
			// Report
			Siberix.Report.Report report = new Siberix.Report.Report();

			// Info
			report.Info.Title = "Example";
			report.Info.Author = "Siberix Technologies, Canada";
			report.Info.Creator = "Siberix Report Writer";
			report.Info.Copyright = "2003-2012 Siberix Technologies, Canada";

			// You can use the following lines to create test certificates. Makecert.exe is a part of Visual Studio 2010 SDK.

			// makecert.exe -n "CN=MyRootCert" -cy authority -m 12 -r -ss "Root" -sr "LocalMachine"
			// makecert.exe -n "CN=MyCert1" -cy end -m 12 -is "Root" -in "MyRootCert" -ir "LocalMachine" -ss "My" -sr "CurrentUser"

			// Signature
			X509Store store = new X509Store(StoreName.My, StoreLocation.CurrentUser);
			
			store.Open(OpenFlags.ReadOnly);
	
			X509Certificate2Collection certificates = store.Certificates.Find(X509FindType.FindBySubjectName, "MyCert1", true);
			
			store.Close();

			report.Preferences.PDF.Signature.Certificate = certificates[0];
			report.Preferences.PDF.Signature.Reason = "I agree...";
			report.Preferences.PDF.Signature.Location = "Canada";
			report.Preferences.PDF.Signature.ContactInfo = "Phone: (778) 855-0655";

			// Section
			Siberix.Report.Section.ISection section = report.AddSection();
			section.Size = Siberix.Report.PageSize.Letter;
			section.Spacings.All = 35;

			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(12), Siberix.Graphics.Brushes.Black);

			Siberix.Report.Text.IText text = section.AddText();
			text.Style = style1;
			text.AddContent("This document is signed.");

			// Publish
			report.Publish("Document.pdf", Siberix.Report.FileFormat.PDF);

			// View
			System.Diagnostics.Process process = new System.Diagnostics.Process();
			System.Diagnostics.ProcessStartInfo info = new System.Diagnostics.ProcessStartInfo("Document.pdf");
			process.StartInfo = info;
			process.Start();
		}
	}
}