Imports System
Imports System.Collections.Generic

Module Example

    Private Class Person

        Public Sub New()

        End Sub

        Public Property Name As String
        Public Property Birthday As DateTime
        Public Property Level As Integer
        Public Property Tasks As List(Of Task)

    End Class

    Private Class Task

        Public Sub New()

        End Sub

        Public Property Id As String
        Public Property Description As String

    End Class

    Private Class ValueFormatter
        Implements Siberix.Report.Data.IValueFormatter

        Public Sub New()

        End Sub

        Public ReadOnly Property Id() As String Implements Siberix.Report.Data.IValueFormatter.Id

            Get
                Return "vf1"
            End Get

        End Property

        Public Function Format(ByVal value As Object) As String Implements Siberix.Report.Data.IValueFormatter.Format

            If value <> Nothing Then

                Dim dt As DateTime = CType(value, DateTime)

                Return "[ " + dt.Year.ToString() + " / " + dt.ToString("MMM") + " / " + dt.Day.ToString() + " ]"

            End If

            Return Nothing

        End Function

    End Class

    Sub Main()

        Dim person1 As Person = New Person() With {.Name = "John", .Level = 3}
        Dim person2 As Person = New Person() With {.Name = "Alex", .Level = 2}
        Dim person3 As Person = New Person() With {.Name = "Bob", .Level = 7}
        Dim person4 As Person = New Person() With {.Name = "Scott", .Level = 1, .Birthday = New DateTime(1965, 10, 23)}

        Dim tasks As List(Of Task) = New List(Of Task)

        tasks.Add(New Task() With {.Id = "1-A11", .Description = "Task 1"})
        tasks.Add(New Task() With {.Id = "2-B22", .Description = "Task 2"})
        tasks.Add(New Task() With {.Id = "3-C33", .Description = "Task 3"})
        tasks.Add(New Task() With {.Id = "4-D44", .Description = "Task 4"})

        Dim person5 As Person = New Person() With {.Name = "Nick", .Level = 1, .Birthday = New DateTime(1975, 7, 16), .Tasks = tasks}

        ' Report
        Dim report As Siberix.Report.Report = New Siberix.Report.Report()

        ' Info
        report.Info.Title = "Example"
        report.Info.Author = "Siberix Technologies, Canada"
        report.Info.Creator = "Siberix Report Writer"
        report.Info.Copyright = "2003-2012 Siberix Technologies, Canada"

        report.DataContext = New Siberix.Report.Data.DataContext("dc4", person4)

        ' Section
        Dim section As Siberix.Report.Section.ISection = report.AddSection()
        section.Size = Siberix.Report.PageSize.Letter
        section.Spacings.All = 35

        ' Styles
        Dim style1 As Siberix.Report.Text.Style = New Siberix.Report.Text.Style(New Siberix.Graphics.Fonts.Arial(15), Siberix.Graphics.Brushes.Black)
        Dim style2 As Siberix.Report.Text.Style = New Siberix.Report.Text.Style(New Siberix.Graphics.Fonts.Arial(15), Siberix.Graphics.Brushes.Red)

        ' Binding to the text.DataContext
        Dim text As Siberix.Report.Text.IText = section.AddText()
        text.DataContext = New Siberix.Report.Data.DataContext("dc1", person1)
        text.Binding = New Report.Data.DataBinding("Name")
        text.Style = style1



        ' Binding with Formatter
        text = section.AddText()
        text.DataContext = New Siberix.Report.Data.DataContext("dc2", person2)
        text.Binding = New Report.Data.DataBinding("Level", "Level: {0}")
        text.Style = style1



        ' Binding text to the parent DataContext with ValueFormatter
        text = section.AddText()
        text.Binding = New Report.Data.DataBinding("Birthday", "Birthday: *** {0} ***", New ValueFormatter())
        text.Style = style1



        ' Binding text to a specific DataContext
        text = section.AddText()
        text.Binding = New Report.Data.DataBinding(New Siberix.Report.Data.DataContext("dc3", person3), "Name", "Name: {0}")
        text.Style = style1



        ' Binding repeater to a collection of objects
        Dim repeater As Siberix.Report.Repeater.IRepeater = section.AddRepeater()
        repeater.DataContext = New Siberix.Report.Data.DataContext("dc5", person5)
        repeater.Binding = New Siberix.Report.Data.DataBinding("Tasks")
        repeater.Spacings.Top = 25

        ' Repeater item template
        Dim repeaterItemTemplate As Siberix.Report.Repeater.IItemTemplate = repeater.AddItemTemplate()

        text = repeaterItemTemplate.AddText()
        text.Binding = New Siberix.Report.Data.DataBinding("Description")
        text.Style = style1



        ' Binding list to a collection of objects
        Dim list As Siberix.Report.List.IList = section.AddList()
        list.DataContext = New Siberix.Report.Data.DataContext("dc5", person5)
        list.Binding = New Siberix.Report.Data.DataBinding("Tasks")
        list.Spacings.Top = 25

        ' List item template
        Dim listItemTemplate As Siberix.Report.List.IItemTemplate = list.AddItemTemplate()

        text = listItemTemplate.AddText()
        text.Binding = New Siberix.Report.Data.DataBinding("Id")
        text.Style = style1

        text = listItemTemplate.AddText()
        text.Binding = New Siberix.Report.Data.DataBinding("Description", ": [ {0} ]")
        text.Style = style2



        ' Binding grid to a collection of objects
        Dim grid As Siberix.Report.Grid.IGrid = section.AddGrid()
        grid.DataContext = New Siberix.Report.Data.DataContext("dc5", person5)
        grid.Binding = New Siberix.Report.Data.DataBinding("Tasks")
        grid.Spacings.Top = 25
        grid.Borders = New Siberix.Report.Borders(Siberix.Graphics.Pens.Black)

        Dim column As Siberix.Report.Grid.IColumn = grid.AddColumn()
        column.Width = New Siberix.Report.RelativeWidth(20)

        column = grid.AddColumn()
        column.Width = New Siberix.Report.RelativeWidth(80)

        Dim header As Siberix.Report.Grid.IHeader = grid.AddHeader()

        Dim row As Siberix.Report.Grid.IRow = header.AddRow()

        Dim cell As Siberix.Report.Grid.ICell = row.AddCell()
        cell.Borders = New Siberix.Report.Borders(Siberix.Graphics.Pens.Black)
        cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Middle
        cell.Paddings.All = 5
        cell.Background.Brush = Siberix.Graphics.Brushes.LightSkyBlue

        text = cell.AddText()
        text.Style = style1
        text.AddContent("Id")

        cell = row.AddCell()
        cell.ColSpan = 4
        cell.Borders = New Siberix.Report.Borders(Siberix.Graphics.Pens.Black)
        cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Middle
        cell.Paddings.All = 5
        cell.Background.Brush = Siberix.Graphics.Brushes.LightYellow

        text = cell.AddText()
        text.Style = style1
        text.AddContent("Description")

        ' Grid row template
        Dim gridRowTemplate As Siberix.Report.Grid.IRowTemplate = grid.AddRowTemplate()

        cell = gridRowTemplate.AddCell()
        cell.Borders = New Siberix.Report.Borders(Siberix.Graphics.Pens.Black)
        cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Middle
        cell.Paddings.All = 5

        text = cell.AddText()
        text.Binding = New Siberix.Report.Data.DataBinding("Id")
        text.Style = style1

        cell = gridRowTemplate.AddCell()
        cell.Borders = New Siberix.Report.Borders(Siberix.Graphics.Pens.Black)
        cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Middle
        cell.Paddings.All = 5

        text = cell.AddText()
        text.Binding = New Siberix.Report.Data.DataBinding("Description", "--- {0} ---")
        text.Style = style2

        ' Publish
        report.Publish("Document.pdf", Siberix.Report.FileFormat.PDF)
        report.Publish("Document.xps", Siberix.Report.FileFormat.XPS)

        ' Save
        report.Save("Report.xml")

        ' View
        Dim process As System.Diagnostics.Process = New System.Diagnostics.Process()
        Dim info As System.Diagnostics.ProcessStartInfo = New System.Diagnostics.ProcessStartInfo("Document.pdf")
        process.StartInfo = info
        process.Start()

    End Sub

End Module
