Imports System
Imports System.Collections.Generic

Module Example

    Sub Main()

        ' Report
        Dim report As Siberix.Report.Report = New Siberix.Report.Report()

        ' Info
        report.Info.Title = "Example"
        report.Info.Author = "Siberix Technologies, Canada"
        report.Info.Creator = "Siberix Report Writer"
        report.Info.Copyright = "2003-2012 Siberix Technologies, Canada"

        ' Section
        Dim section As Siberix.Report.Section.ISection = report.AddSection()
        section.Size = Siberix.Report.PageSize.Letter
        section.Spacings.All = 35

        ' Styles
        Dim style1 As Siberix.Report.Text.Style = New Siberix.Report.Text.Style(New Siberix.Graphics.Fonts.Arial(10), Siberix.Graphics.Brushes.Black)
        Dim style2 As Siberix.Report.Text.Style = New Siberix.Report.Text.Style(New Siberix.Graphics.Fonts.Arial(135), New Siberix.Graphics.SolidColorBrush(New Siberix.Graphics.Color(240, 240, 240)))

        ' Page Numbering
        Dim footer As Siberix.Report.Section.IFooter = section.AddFooter()
        footer.Height = New Siberix.Report.DirectHeight(30)

        Dim pn As Siberix.Report.IPageNumber = footer.AddPageNumber(600, 5)
        pn.Style = style1
        pn.Format = Siberix.Report.NumberFormat.Decimal
        pn.Template = "Page {0} of {1}"
        pn.Alignment = Siberix.Report.NumberAlignment.Right

        ' Watermark
        Dim watermark As Siberix.Report.Section.IWatermark = section.AddWatermark()
        watermark.Repeat = True

        Dim text As Siberix.Report.Text.IText = watermark.AddText(0, 0, -45)
        text.Style = style2
        text.AddContent("TOC")

        ' Bookmarks
        report.AddBookmark("ContentsRef", "Contents", False)
        report.AddBookmark("TextRef", "Text", False)
        report.AddBookmark("ImageRef", "Image", False)
        report.AddBookmark("ListRef", "List", False)

        AddCaption(section, Siberix.Graphics.Brushes.DarkBlue, 15, "ContentsRef", "Contents")
        AddContents(section)

        section.AddPageBreak()
        AddCaption(section, Siberix.Graphics.Brushes.DarkRed, 10, "TextRef", "Text")
        section.AddPageBreak()
        AddCaption(section, Siberix.Graphics.Brushes.DarkOrange, 10, "ImageRef", "Image")
        section.AddPageBreak()
        AddCaption(section, Siberix.Graphics.Brushes.DarkGreen, 10, "ListRef", "List")

        ' Publish
        report.Publish("Document.pdf", Siberix.Report.FileFormat.PDF)
        report.Publish("Document.xps", Siberix.Report.FileFormat.XPS)

        ' Save
        report.Save("Report.xml")

        ' View
        Dim process As System.Diagnostics.Process = New System.Diagnostics.Process()
        Dim info As System.Diagnostics.ProcessStartInfo = New System.Diagnostics.ProcessStartInfo("Document.pdf")
        process.StartInfo = info
        process.Start()

    End Sub

    Sub AddCaption(ByVal section As Siberix.Report.Section.ISection, ByVal bgbrush As Siberix.Graphics.Brush, ByVal width As Single, ByVal id As String, ByVal caption As String)

        Dim style1 As Siberix.Report.Text.Style = New Siberix.Report.Text.Style(New Siberix.Graphics.Fonts.Arial(12), Siberix.Graphics.Brushes.White)

        Dim group As Siberix.Report.IGroup = section.AddGroup()
        group.Width = New Siberix.Report.RelativeWidth(width)
        group.Background.Brush = bgbrush
        group.Borders.Corners.All = New Siberix.Report.Corner(Nothing, 5)
        group.Borders.Corners.TopRight = New Siberix.Report.Corner(Nothing, 10)
        group.Borders.Corners.BottomRight = New Siberix.Report.Corner(Nothing, 10)
        group.Paddings.All = 5
        group.Spacings.Top = 20
        group.Spacings.Bottom = 15
        group.KeepWithNext = True

        Dim text As Siberix.Report.Text.IText = group.AddText()
        text.Style = style1
        text.Id = id
        text.AddContent(caption)

    End Sub

    Sub AddContents(ByVal section As Siberix.Report.Section.ISection)

        ' Styles
        Dim style1 As Siberix.Report.Text.Style = New Siberix.Report.Text.Style(New Siberix.Graphics.Fonts.Arial(12), Siberix.Graphics.Brushes.Black)

        ' Contents
        Dim grid As Siberix.Report.Grid.IGrid = section.AddGrid()
        grid.Width = New Siberix.Report.RelativeWidth(70)

        Dim column As Siberix.Report.Grid.IColumn = grid.AddColumn()
        column.Width = New Siberix.Report.RelativeWidth(90)

        column = grid.AddColumn()
        column.Width = New Siberix.Report.RelativeWidth(10)

        ' Text
        Dim row As Siberix.Report.Grid.IRow = grid.AddRow()
        row.Spacings.Top = 5

        Dim cell As Siberix.Report.Grid.ICell = row.AddCell()

        Dim text As Siberix.Report.Text.IText = cell.AddText()
        text.Style = style1
        text.Leader = New Siberix.Report.Text.Leader(".")
        text.Width = New Siberix.Report.RelativeWidth(100)
        text.AddContent("Text", New Siberix.Report.Text.Hyperlink("TextRef"))

        cell = row.AddCell()

        Dim pr As Siberix.Report.IPageReference = cell.AddPageReference("TextRef")
        pr.Style = style1
        pr.Alignment = Siberix.Report.NumberAlignment.Left

        ' Image
        row = grid.AddRow()
        row.Spacings.Top = 5

        cell = row.AddCell()

        text = cell.AddText()
        text.Style = style1
        text.Leader = New Siberix.Report.Text.Leader(".")
        text.Width = New Siberix.Report.RelativeWidth(100)
        text.AddContent("Image", New Siberix.Report.Text.Hyperlink("ImageRef"))

        cell = row.AddCell()

        pr = cell.AddPageReference("ImageRef")
        pr.Style = style1
        pr.Alignment = Siberix.Report.NumberAlignment.Left

        ' List
        row = grid.AddRow()
        row.Spacings.Top = 5

        cell = row.AddCell()

        text = cell.AddText()
        text.Style = style1
        text.Leader = New Siberix.Report.Text.Leader(".")
        text.Width = New Siberix.Report.RelativeWidth(100)
        text.AddContent("List", New Siberix.Report.Text.Hyperlink("ListRef"))

        cell = row.AddCell()

        pr = cell.AddPageReference("ListRef")
        pr.Style = style1
        pr.Alignment = Siberix.Report.NumberAlignment.Left

    End Sub

End Module
